@@ -73,17 +73,11 @@ subscription_dialog_response_cb (GtkDialog *dialog,
 	contact = empathy_contact_widget_get_contact (contact_widget);
 
 	if (response == GTK_RESPONSE_YES) {
-		EmpathyTpContactFactory *factory;
-
-		factory = empathy_tp_contact_factory_dup_singleton (
-			empathy_contact_get_connection (contact));
-
 		empathy_contact_list_add (EMPATHY_CONTACT_LIST (manager),
 					  contact, "");
-		empathy_tp_contact_factory_set_alias (factory, contact,
-			empathy_contact_widget_get_alias (contact_widget));
 
-		g_object_unref (factory);
+		empathy_contact_set_alias (contact,
+			empathy_contact_widget_get_alias (contact_widget));
 	}
 	else if (response == GTK_RESPONSE_NO) {
 		empathy_contact_list_remove (EMPATHY_CONTACT_LIST (manager),
@@ -202,7 +196,7 @@ empathy_contact_information_dialog_show (EmpathyContact *contact,
 	/* Contact info widget */
 	contact_widget = empathy_contact_widget_new (contact,
 		EMPATHY_CONTACT_WIDGET_SHOW_LOCATION |
-		EMPATHY_CONTACT_WIDGET_EDIT_NONE);
+		EMPATHY_CONTACT_WIDGET_SHOW_DETAILS);
 	gtk_container_set_border_width (GTK_CONTAINER (contact_widget), 8);
 	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))),
 			    contact_widget,
@@ -261,7 +255,8 @@ empathy_contact_edit_dialog_show (EmpathyContact *contact,
 	/* Contact info widget */
 	contact_widget = empathy_contact_widget_new (contact,
 		EMPATHY_CONTACT_WIDGET_EDIT_ALIAS |
-		EMPATHY_CONTACT_WIDGET_EDIT_GROUPS);
+		EMPATHY_CONTACT_WIDGET_EDIT_GROUPS |
+		EMPATHY_CONTACT_WIDGET_EDIT_FAVOURITE);
 	gtk_container_set_border_width (GTK_CONTAINER (contact_widget), 8);
 	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))),
 			    contact_widget,
@@ -313,7 +308,8 @@ empathy_contact_personal_dialog_show (GtkWindow *parent)
 	contact_widget = empathy_contact_widget_new (NULL,
 		EMPATHY_CONTACT_WIDGET_EDIT_ACCOUNT |
 		EMPATHY_CONTACT_WIDGET_EDIT_ALIAS |
-		EMPATHY_CONTACT_WIDGET_EDIT_AVATAR);
+		EMPATHY_CONTACT_WIDGET_EDIT_AVATAR |
+		EMPATHY_CONTACT_WIDGET_EDIT_DETAILS);
 	gtk_container_set_border_width (GTK_CONTAINER (contact_widget), 8);
 	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (personal_dialog))),
 			    contact_widget,
