@@ -41,7 +41,6 @@
 #include "empathy-ui-utils.h"
 #include "empathy-images.h"
 #include "empathy-smiley-manager.h"
-#include "empathy-conf.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
 #include <libempathy/empathy-debug.h>
@@ -78,6 +77,7 @@ builder_get_file_valist (const gchar *filename,
 	DEBUG ("Loading file %s", filename);
 
 	gui = gtk_builder_new ();
+	gtk_builder_set_translation_domain (gui, GETTEXT_PACKAGE);
 	if (!gtk_builder_add_from_file (gui, filename, &error)) {
 		g_critical ("GtkBuilder Error (%s): %s",
 				filename, error->message);
@@ -181,7 +181,13 @@ empathy_icon_name_for_presence (TpConnectionPresenceType presence)
 	case TP_CONNECTION_PRESENCE_TYPE_AWAY:
 		return EMPATHY_IMAGE_AWAY;
 	case TP_CONNECTION_PRESENCE_TYPE_EXTENDED_AWAY:
-		return EMPATHY_IMAGE_EXT_AWAY;
+		if (gtk_icon_theme_has_icon (gtk_icon_theme_get_default (),
+					     EMPATHY_IMAGE_EXT_AWAY))
+			return EMPATHY_IMAGE_EXT_AWAY;
+
+		/* The 'extended-away' icon is not an official one so we fallback to idle if
+		 * it's not implemented */
+		return EMPATHY_IMAGE_IDLE;
 	case TP_CONNECTION_PRESENCE_TYPE_HIDDEN:
 		if (gtk_icon_theme_has_icon (gtk_icon_theme_get_default (),
 					     EMPATHY_IMAGE_HIDDEN))
@@ -533,13 +539,14 @@ empathy_pixbuf_contact_status_icon_with_icon_name (EmpathyContact *contact,
 
 	pix_status = gdk_pixbuf_new_from_file (icon_filename, NULL);
 
-	g_free (icon_filename);
-
 	if (pix_status == NULL) {
 		DEBUG ("Could not open icon %s\n", icon_filename);
+		g_free (icon_filename);
 		return NULL;
 	}
 
+	g_free (icon_filename);
+
 	if (!show_protocol)
 		return pix_status;
 
@@ -1521,28 +1528,6 @@ empathy_url_show (GtkWidget *parent,
 	g_free (real_url);
 }
 
-static void
-link_button_hook (GtkLinkButton *button,
-		  const gchar *link,
-		  gpointer user_data)
-{
-	empathy_url_show (GTK_WIDGET (button), link);
-}
-
-GtkWidget *
-empathy_link_button_new (const gchar *url,
-			const gchar *title)
-{
-	static gboolean hook = FALSE;
-
-	if (!hook) {
-		hook = TRUE;
-		gtk_link_button_set_uri_hook (link_button_hook, NULL, NULL);
-	}
-
-	return gtk_link_button_new_with_label (url, title);
-}
-
 void
 empathy_send_file (EmpathyContact *contact, GFile *file)
 {
@@ -1686,8 +1671,16 @@ empathy_receive_file_with_file_chooser (EmpathyFTHandler *handler)
 {
 	GtkWidget *widget;
 	const gchar *dir;
+	EmpathyContact *contact;
+	gchar *title;
 
-	widget = gtk_file_chooser_dialog_new (_("Select a destination"),
+	contact = empathy_ft_handler_get_contact (handler);
+	g_assert (contact != NULL);
+
+	title = g_strdup_printf (_("Incoming file from %s"),
+		empathy_contact_get_name (contact));
+
+	widget = gtk_file_chooser_dialog_new (title,
 					      NULL,
 					      GTK_FILE_CHOOSER_ACTION_SAVE,
 					      GTK_STOCK_CANCEL,
@@ -1711,5 +1704,5 @@ empathy_receive_file_with_file_chooser (EmpathyFTHandler *handler)
 		G_CALLBACK (file_manager_receive_file_response_cb), handler);
 
 	gtk_widget_show (widget);
+	g_free (title);
 }
-
