@@ -32,6 +32,7 @@
 
 #include <telepathy-glib/account-manager.h>
 #include <telepathy-glib/interfaces.h>
+#include <telepathy-glib/util.h>
 
 #include "empathy-tp-chat.h"
 #include "empathy-chatroom-manager.h"
@@ -112,12 +113,15 @@ chatroom_manager_file_save (EmpathyChatroomManager *manager)
 		xmlNewTextChild (node, NULL, (const xmlChar *) "name",
 			(const xmlChar *) empathy_chatroom_get_name (chatroom));
 		xmlNewTextChild (node, NULL, (const xmlChar *) "room",
-			(const xmlChar *) empathy_chatroom_get_name (chatroom));
+			(const xmlChar *) empathy_chatroom_get_room (chatroom));
 		xmlNewTextChild (node, NULL, (const xmlChar *) "account",
 			(const xmlChar *) account_id);
 		xmlNewTextChild (node, NULL, (const xmlChar *) "auto_connect",
 			empathy_chatroom_get_auto_connect (chatroom) ?
 			(const xmlChar *) "yes" : (const xmlChar *) "no");
+		xmlNewTextChild (node, NULL, (const xmlChar *) "always_urgent",
+			empathy_chatroom_is_always_urgent (chatroom) ?
+			(const xmlChar *) "yes" : (const xmlChar *) "no");
 	}
 
 	/* Make sure the XML is indented properly */
@@ -127,7 +131,6 @@ chatroom_manager_file_save (EmpathyChatroomManager *manager)
 	xmlSaveFormatFileEnc (priv->file, doc, "utf-8", 1);
 	xmlFreeDoc (doc);
 
-	xmlCleanupParser ();
 	xmlMemoryDump ();
 
 	return TRUE;
@@ -191,6 +194,7 @@ chatroom_manager_parse_chatroom (EmpathyChatroomManager *manager,
 	gchar                     *room;
 	gchar                     *account_id;
 	gboolean                   auto_connect;
+	gboolean                   always_urgent;
 
 	priv = GET_PRIV (manager);
 
@@ -198,6 +202,7 @@ chatroom_manager_parse_chatroom (EmpathyChatroomManager *manager,
 	name = NULL;
 	room = NULL;
 	auto_connect = TRUE;
+	always_urgent = FALSE;
 	account_id = NULL;
 
 	for (child = node->children; child; child = child->next) {
@@ -223,6 +228,13 @@ chatroom_manager_parse_chatroom (EmpathyChatroomManager *manager,
 				auto_connect = FALSE;
 			}
 		}
+		else if (!tp_strdiff (tag, "always_urgent")) {
+			if (strcmp (str, "yes") == 0) {
+				always_urgent = TRUE;
+			} else {
+				always_urgent = FALSE;
+			}
+		}
 		else if (strcmp (tag, "account") == 0) {
 			account_id = g_strdup (str);
 		}
@@ -241,6 +253,7 @@ chatroom_manager_parse_chatroom (EmpathyChatroomManager *manager,
 
 	chatroom = empathy_chatroom_new_full (account, room, name, auto_connect);
 	empathy_chatroom_set_favorite (chatroom, TRUE);
+	empathy_chatroom_set_always_urgent (chatroom, always_urgent);
 	add_chatroom (manager, chatroom);
 	g_signal_emit (manager, signals[CHATROOM_ADDED], 0, chatroom);
 
@@ -633,6 +646,28 @@ empathy_chatroom_manager_find (EmpathyChatroomManager *manager,
 	return NULL;
 }
 
+EmpathyChatroom *
+empathy_chatroom_manager_ensure_chatroom (EmpathyChatroomManager *manager,
+					  TpAccount *account,
+					  const gchar *room,
+					  const gchar *name)
+{
+	EmpathyChatroom *chatroom;
+
+	chatroom = empathy_chatroom_manager_find (manager, account, room);
+
+	if (chatroom) {
+		return g_object_ref (chatroom);
+	} else {
+		chatroom = empathy_chatroom_new_full (account,
+			room,
+			name,
+			FALSE);
+		empathy_chatroom_manager_add (manager, chatroom);
+		return chatroom;
+	}
+}
+
 GList *
 empathy_chatroom_manager_get_chatrooms (EmpathyChatroomManager *manager,
 				       TpAccount *account)
@@ -719,46 +754,25 @@ chatroom_manager_chat_destroyed_cb (EmpathyTpChat *chat,
     }
 }
 
-static void
-chatroom_manager_observe_channel_cb (EmpathyDispatcher *dispatcher,
-  EmpathyDispatchOperation *operation, gpointer manager)
+/* Called by EmpathyChatManager when we are handling a new group chat */
+void
+empathy_chatroom_manager_chat_handled (EmpathyChatroomManager *self,
+    EmpathyTpChat *chat,
+    TpAccount *account)
 {
   EmpathyChatroom *chatroom;
-  TpChannel *channel;
-  EmpathyTpChat *chat;
   const gchar *roomname;
-  GQuark channel_type;
-  TpHandleType handle_type;
-  TpAccount *account;
-  TpConnection *connection;
-
-  channel_type = empathy_dispatch_operation_get_channel_type_id (operation);
-
-  /* Observe Text channels to rooms only */
-  if (channel_type != TP_IFACE_QUARK_CHANNEL_TYPE_TEXT)
-    return;
-
-  channel = empathy_dispatch_operation_get_channel (operation);
-  tp_channel_get_handle (channel, &handle_type);
-
-  if (handle_type != TP_HANDLE_TYPE_ROOM)
-    return;
-
-  chat = EMPATHY_TP_CHAT (
-    empathy_dispatch_operation_get_channel_wrapper (operation));
-  connection = empathy_tp_chat_get_connection (chat);
-  account = empathy_get_account_for_connection (connection);
 
   roomname = empathy_tp_chat_get_id (chat);
 
-  chatroom = empathy_chatroom_manager_find (manager, account, roomname);
+  chatroom = empathy_chatroom_manager_find (self, account, roomname);
 
   if (chatroom == NULL)
     {
       chatroom = empathy_chatroom_new_full (account, roomname, roomname,
         FALSE);
       empathy_chatroom_set_tp_chat (chatroom, chat);
-      empathy_chatroom_manager_add (manager, chatroom);
+      empathy_chatroom_manager_add (self, chatroom);
       g_object_unref (chatroom);
     }
   else
@@ -770,13 +784,5 @@ chatroom_manager_observe_channel_cb (EmpathyDispatcher *dispatcher,
    * has been invalidated in the dispatcher..  */
   g_signal_connect (chat, "destroy",
     G_CALLBACK (chatroom_manager_chat_destroyed_cb),
-    manager);
-}
-
-void
-empathy_chatroom_manager_observe (EmpathyChatroomManager *manager,
-  EmpathyDispatcher *dispatcher)
-{
-  g_signal_connect (dispatcher, "observe",
-    G_CALLBACK (chatroom_manager_observe_channel_cb), manager);
+    self);
 }
