@@ -76,9 +76,6 @@ GType empathy_tp_call_get_type (void) G_GNUC_CONST;
 EmpathyTpCall *empathy_tp_call_new (TpChannel *channel);
 void empathy_tp_call_close (EmpathyTpCall *call);
 
-void empathy_tp_call_to (EmpathyTpCall *call, EmpathyContact *contact,
-  gboolean audio, gboolean video);
-
 void empathy_tp_call_accept_incoming_call (EmpathyTpCall *call);
 void empathy_tp_call_request_video_stream_direction (EmpathyTpCall *call,
     gboolean is_sending);
@@ -92,6 +89,10 @@ const gchar * empathy_tp_call_get_connection_manager (EmpathyTpCall *self);
 
 gboolean empathy_tp_call_has_initial_video (EmpathyTpCall *self);
 
+void empathy_tp_call_leave (EmpathyTpCall *self);
+
+EmpathyTpCallStatus empathy_tp_call_get_status (EmpathyTpCall *self);
+
 G_END_DECLS
 
 #endif /* __EMPATHY_TP_CALL_H__ */
