@@ -36,7 +36,6 @@
 #include <libempathy-gtk/empathy-account-widget.h>
 #include <libempathy-gtk/empathy-protocol-chooser.h>
 #include <libempathy-gtk/empathy-ui-utils.h>
-#include <libempathy-gtk/empathy-conf.h>
 
 #define DEBUG_FLAG EMPATHY_DEBUG_ACCOUNT
 #include <libempathy/empathy-debug.h>
@@ -428,6 +427,9 @@ account_assistant_protocol_changed_cb (GtkComboBox *chooser,
     {
       empathy_account_settings_set_icon_name_async (settings, "im-facebook",
         NULL, NULL);
+
+      empathy_account_settings_set_string (settings, "server",
+          "chat.facebook.com");
     }
 
   if (priv->first_resp == RESPONSE_CREATE_ACCOUNT)
@@ -910,6 +912,10 @@ impl_signal_apply (GtkAssistant *assistant)
       g_object_unref (priv->settings);
       priv->settings = NULL;
     }
+  else if (current_page == PAGE_IMPORT)
+    {
+      empathy_import_widget_add_selected_accounts (priv->iw);
+    }
 }
 
 static void
